@@ -14,6 +14,8 @@ class _tpl_curve:
       gen_cls = _tpl_curve_generator_ybar
     elif type == 'interval' or type == 'ybar interval':
       gen_cls = _tpl_curve_generator_ybarinterval
+    elif type == 'lines' or type == 'line' or type == 'continuous':
+      gen_cls = _tpl_curve_generator_lines
     else:
       print(f"Cannot identify plottype \"{type}\". Keeping previous type (default: xy).")
       return
